@@ -1,8 +1,10 @@
 package Redis::Client::Role::Tied;
 {
-  $Redis::Client::Role::Tied::VERSION = '0.002';
+  $Redis::Client::Role::Tied::VERSION = '0.009';
 }
 
+# ABSTRACT: Role for tied things that talk to Redis
+
 use Moose::Role;
 use Carp 'croak';
 use Scalar::Util 'blessed';
@@ -37,11 +39,11 @@ sub _cmd {
 
 =head1 NAME
 
-Redis::Client::Role::Tied
+Redis::Client::Role::Tied - Role for tied things that talk to Redis
 
 =head1 VERSION
 
-version 0.002
+version 0.009
 
 =head1 DESCRIPTION
 
@@ -67,6 +69,14 @@ This role contains common functionality used by the Redis::Client C<tie> classes
 
 =back
 
+=head1 CONSUMES
+
+=over 4
+
+=item * L<Redis::Client::Role::Tied>
+
+=back
+
 =head1 AUTHOR
 
 Mike Friedman <friedo@friedo.com>
